import { useContext, useMemo } from 'react';
import PdeContext from '../../contexts/PdeContext';
import { getPlatformStrategy } from './platformStrategies';
/**
 * Hook to use a experiment
 * @param {object} param
 * @param {string} param.experimentName
 * @param {object} param.attributes
 * @param {function} param.trackExperimentViewed
 * @return {{variation: string}}
 */

export default function useExperiment(_temp) {
  var _ref = _temp === void 0 ? {} : _temp,
      experimentName = _ref.experimentName,
      attributes = _ref.attributes,
      trackExperimentViewed = _ref.trackExperimentViewed;

  var _useContext = useContext(PdeContext),
      pde = _useContext.pde;

  if (pde === null) throw new Error('[sui-pde: useExperiment] sui-pde provider is required to work');
  var variation = useMemo(function () {
    var variationName;
    var strategy = getPlatformStrategy({
      customTrackExperimentViewed: trackExperimentViewed
    });

    try {
      variationName = strategy.getVariation({
        pde: pde,
        experimentName: experimentName,
        attributes: attributes
      });
      strategy.trackExperiment({
        variationName: variationName,
        experimentName: experimentName
      });
    } catch (error) {
      // eslint-disable-next-line no-console
      console.error(error);
      return null;
    }

    return variationName;
  }, [experimentName, pde, attributes, trackExperimentViewed]);
  return {
    variation: variation
  };
}