var getServerStrategy = function getServerStrategy() {
  return {
    getVariation: function getVariation(_ref) {
      var pde = _ref.pde,
          experimentName = _ref.experimentName,
          attributes = _ref.attributes;
      return pde.getVariation({
        pde: pde,
        name: experimentName,
        attributes: attributes
      });
    },
    trackExperiment: function trackExperiment() {}
  };
};

var getBrowserStrategy = function getBrowserStrategy(_ref2) {
  var customTrackExperimentViewed = _ref2.customTrackExperimentViewed;
  return {
    getVariation: function getVariation(_ref3) {
      var pde = _ref3.pde,
          experimentName = _ref3.experimentName,
          attributes = _ref3.attributes;
      var variationName = pde.activateExperiment({
        name: experimentName,
        attributes: attributes
      });
      return variationName;
    },
    trackExperiment: function trackExperiment(_ref4) {
      var _window$analytics;

      var variationName = _ref4.variationName,
          experimentName = _ref4.experimentName;

      if (customTrackExperimentViewed) {
        return customTrackExperimentViewed({
          variationName: variationName,
          experimentName: experimentName
        });
      } // user is not part of the experiment


      if (!variationName) return;

      if (!((_window$analytics = window.analytics) != null && _window$analytics.track)) {
        // eslint-disable-next-line no-console
        console.error("[sui-pde: useExperiment] window.analytics.track expected to exists but doesn't");
        return;
      }

      window.analytics.ready(function () {
        window.analytics.track('Experiment Viewed', {
          experimentName: experimentName,
          variationName: variationName
        });
      });
    }
  };
};

export var getPlatformStrategy = function getPlatformStrategy(_ref5) {
  var customTrackExperimentViewed = _ref5.customTrackExperimentViewed;
  var isNode = typeof window === 'undefined';

  if (isNode) {
    return getServerStrategy();
  }

  return getBrowserStrategy({
    customTrackExperimentViewed: customTrackExperimentViewed
  });
};